@@ -1,3 +1,4 @@
+import django
 from django import template
 from django.template import Context, loader
 from stream_django.exceptions import MissingDataException
@@ -41,7 +42,12 @@ def render_activity(context, activity, template_prefix='', missing_data_policy=L
 
     tmpl = loader.get_template(template_name)
     context['activity'] = activity
-    context = Context(context)
+
+    if django.VERSION < (1, 11):
+        context = Context(context)
+    elif isinstance(context, Context):
+        context = context.flatten()
+
     return tmpl.render(context)
 
 
